# File Shredder

Advanced file shredding tool that deletes files with no data left using encryption techniques.

## Features

- Delete any file securely and completely with no data left
- Using Encryption and AI techniques
- Shred all files in a directory

## Installation

pip install fshredder

## Usage

fshredder or fshredder.py